==> s3tbx-idepix-ui-5.0.4-20171110.081153-36-sources.jar: org/esa/s3tbx/idepix/ui/actions/Bundle.java <==
package org.esa.s3tbx.idepix.ui.actions;
/** Localizable strings for {@link org.esa.s3tbx.idepix.ui.actions}. */
@javax.annotation.Generated(value="org.netbeans.modules.openide.util.NbBundleProcessor")
class Bundle {
    /**
     * @return <i>Landsat-8 OLI</i>
     * @see IdepixLandsat8Action
     */
    static String CTL_IdepixLandsat8Action_Text() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_IdepixLandsat8Action_Text");
    }
    /**
     * @return <i>MERIS</i>
     * @see IdepixMerisAction
     */
    static String CTL_IdepixMerisAction_Text() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_IdepixMerisAction_Text");
    }
    /**
     * @return <i>MODIS</i>
     * @see IdepixModisAction
     */
    static String CTL_IdepixModisAction_Text() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_IdepixModisAction_Text");
    }
    /**
     * @return <i>Sentinel-3 OLCI</i>
     * @see IdepixOlciAction
     */
    static String CTL_IdepixOlciAction_Text() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_IdepixOlciAction_Text");
    }
    /**
     * @return <i>PROBA-V</i>
     * @see IdepixProbavAction
     */
    static String CTL_IdepixProbavAction_Text() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_IdepixProbavAction_Text");
    }
    /**
     * @return <i>SeaWiFS</i>
     * @see IdepixSeawifsAction
     */
    static String CTL_IdepixSeawifsAction_Text() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_IdepixSeawifsAction_Text");
    }
    /**
     * @return <i>SPOT-VGT</i>
     * @see IdepixVgtAction
     */
    static String CTL_IdepixVgtAction_Text() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_IdepixVgtAction_Text");
    }
    /**
     * @return <i>VIIRS</i>
     * @see IdepixViirsAction
     */
    static String CTL_IdepixViirsAction_Text() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_IdepixViirsAction_Text");
    }
    private Bundle() {}
}

==> s3tbx-idepix-ui-7.0.0-20190402.154105-167-sources.jar: org/esa/s3tbx/idepix/ui/actions/Bundle.java <==
package org.esa.s3tbx.idepix.ui.actions;
/** Localizable strings for {@link org.esa.s3tbx.idepix.ui.actions}. */
@javax.annotation.Generated(value="org.netbeans.modules.openide.util.NbBundleProcessor")
class Bundle {
    /**
     * @return <i>Landsat-8 OLI</i>
     * @see IdepixLandsat8Action
     */
    static String CTL_IdepixLandsat8Action_Text() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_IdepixLandsat8Action_Text");
    }
    /**
     * @return <i>Envisat MERIS</i>
     * @see IdepixMerisAction
     */
    static String CTL_IdepixMerisAction_Text() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_IdepixMerisAction_Text");
    }
    /**
     * @return <i>Terra/Aqua MODIS</i>
     * @see IdepixModisAction
     */
    static String CTL_IdepixModisAction_Text() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_IdepixModisAction_Text");
    }
    /**
     * @return <i>Sentinel-3 OLCI</i>
     * @see IdepixOlciAction
     */
    static String CTL_IdepixOlciAction_Text() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_IdepixOlciAction_Text");
    }
    /**
     * @return <i>PROBA-V</i>
     * @see IdepixProbavAction
     */
    static String CTL_IdepixProbavAction_Text() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_IdepixProbavAction_Text");
    }
    /**
     * @return <i>OrbView-2 SeaWiFS</i>
     * @see IdepixSeawifsAction
     */
    static String CTL_IdepixSeawifsAction_Text() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_IdepixSeawifsAction_Text");
    }
    /**
     * @return <i>SPOT Vegetation</i>
     * @see IdepixVgtAction
     */
    static String CTL_IdepixVgtAction_Text() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_IdepixVgtAction_Text");
    }
    /**
     * @return <i>Suomi NPP VIIRS</i>
     * @see IdepixViirsAction
     */
    static String CTL_IdepixViirsAction_Text() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_IdepixViirsAction_Text");
    }
    private Bundle() {}
}
